/*	Interrupt.java
 *
 *	Example of interrupt handle for PCI-TMC12
 *
 * 
 *
 * 	 This program shows the basic interrupt operation.
 *
 *  	J26 selects CLOCK2 for 80K
 * 	             3
 *  	          +---+
 *  	          |   |
 *  	     800K | o |
 *  	          |+-+|
 *  	   CLOCK2 ||o||
 *     	          || ||
 *    	      80K ||o||
 *          	  |+-+|
 *           	  +---+
 *          	   J26
 *
 *  	J3 feeds CLOCK2 to CLK12
 *    	         1 2
 *   	      +-----+
 *   	   J3 |  +-+|
 *   	      | o|o||
 *   	      |  | ||
 *   	      | o|o||
 *    	      |  +-+|
 *   	      | o o |
 *    	      |     |
 *     	      +-----+
 *
 *  	J25 selects the interrupt source as CH12
 *               J25
 *             +-----+
 *             |     |
 *         CH3 | o o |
 *             |     |
 *         CH6 | o o |
 *             |     |
 *         CH9 | o o |
 *             |+---+|
 *        CH12 ||o o||
 *             |+---+|
 *         EXT | o o |
 *             |     |
 *     (SPARE) | o o |
 *             |     |
 *             +-----+
 *
 *      then you can rocking roll now.
 *
 *
 *
 *	v 0.0 2003.8.7 by moki matsushima
 *
 *	Copyright (c) 2003 ICPDAS, Inc. All  Rights Reserved.
 */
 
import java.io.*;							//For System.in.read()
import com.icpdas.cardio.ixpci.*;					//ICPDAS PCI Series I/O Card packages


public class Interrupt implements IxpciIsr 				//Implement IxpioIsr interrupt class
{
	static int beat = 0;
	static int INT1 = 2;
	static int INT1_NEG_EDGE = 0;
	static IxpciDio din,dout;
	static Ixpci icpdasio1;
	static int fd;
	public void ixpci_isr(int sig)					//Will be call when trigger interrupt
	{
		int rev;
		if ((rev=icpdasio1.setDigitalOut(fd,dout))!=0) System.out.println("DO Error");
		if ((rev=icpdasio1.getDigitalIn(fd,din))!=0) System.out.println("DI Error");
		System.out.print("\rTime beat: "+ beat + "   Digital Output: 0x"+ Integer.toHexString(dout.u16)+ "   Digital Input: 0x"+ Integer.toHexString(din.u16)+ "    <enter> exit   ");
		if (dout.u16 == 0x8000) dout.u16 = 1;
		else dout.u16 <<=1 ;
		beat ++;
	}
	
	public static void main(String[] args) throws java.io.IOException
	{
		int rev;
		Interrupt demo_isr;
		byte a[] = new byte[100];
		icpdasio1=new Ixpci();
		din = new IxpciDio();
		dout = new IxpciDio();
		fd=icpdasio1.open("ixpci1");
		if(fd==-1) System.out.println("Card Open Error Code:"+ fd);
		din.u16 = 0;
		dout.u16 = 1;
		demo_isr = new Interrupt();
		/* INT_CHAN_1, signal for negative edges*/
		rev=icpdasio1.registerInterrupt(fd, INT1, INT1_NEG_EDGE, demo_isr);
		if(rev != 0) System.out.println("Install Interrupt Error Code:"+ rev);
		// counter 2 on chip 3, counter 12 on board, mode 3
		rev=icpdasio1.setCounter(fd,11,0,0xb6,0x9c3f);
		if(rev != 0) System.out.println("Config Counter 1 Error Code:"+ rev);
		while(a[0]!=10)
		{
			System.in.read(a);
		}
		/*Remove Interrupt before program end*/
		rev=icpdasio1.removeInterrupt(fd);
		if(rev != 0) System.out.println("Remove Interrupt Error Code:"+ rev);
		icpdasio1.close(fd);
		System.out.println("End of program");
	}
}
