/*	Example of pattern analog output for PIO-DA16/DA8/DA4.
 *
 *	Example of interrupt handle for PIO-D24.
 *
 *      File level history (record changes for this file here.)
 *
 *      This program outputs analog patterns to channels
 *
 *  	0 - a sine wave pattern,
 *	1 - a random pattern,
 *	2 - a FM that powered by 3 pattern,
 *	3 - a 50% AM pattern,
 *	4 - a 100% AM pattern,
 *	5 - a AM that 30% over modulated pattern.
 *
 *      The analog output may be interfered by system interrupt latency since
 *      this is not a real-time implement.
 *
 *	v 0.0 2003.8.7 by moki matsushima
 *
 *	Copyright (c) 2003 ICPDAS, Inc. All  Rights Reserved.
 */
 
import java.io.*;							//For System.in.read()
import com.icpdas.cardio.ixpio.*;					//ICPDAS PIO Series I/O Card packages

public class AoPat 
{
	static int INT = 1;						/* INT0 */
	static int INT_EDGE = 1;					/* negative edge */
	public static void main(String[] args) throws java.io.IOException
	{
		int rev;
		int fd;
		int sw = 1;
		IxpioAio ao = new IxpioAio();
		Pattern pat = new Pattern();
		byte a[] = new byte[100];
		Ixpio icpdasio1=new Ixpio();
		fd=icpdasio1.open("ixpio1");
		if(fd==-1) System.out.println("Card Open Error Code:"+ fd);
		/* install analog pattern */
		ao.channel = 0;
		//ao.sig.is = INT;
		//ao.sig.edge = INT_EDGE;
		ao.is = INT;
		ao.edge = INT_EDGE;
		ao.data = pat.data1;
		ao.data_size = pat.DATA1_SIZE;
		ao.id = 1;
		if((rev=icpdasio1.setAnalogOutPat(fd,ao))!=0) System.out.println("AnalogOut Error Code:"+ rev);
		//ao.sig.is = INT;
		//ao.sig.edge = INT_EDGE;		
		ao.id = 2;
		ao.channel = 1;
		ao.data = pat.data2;
		ao.data_size = pat.DATA2_SIZE;
		if((rev=icpdasio1.setAnalogOutPatAdd(fd,ao))!=0) System.out.println("AnalogOutAdd Error Code:"+ rev);
		//ao.sig.is = INT;
		//ao.sig.edge = INT_EDGE;		
		ao.id = 3;
		ao.data = pat.data3;
		ao.channel = 2;
		ao.data_size = pat.DATA3_SIZE;
		if((rev=icpdasio1.setAnalogOutPatAdd(fd,ao))!=0) System.out.println("AnalogOutAdd Error Code:"+ rev);
		//ao.sig.is = INT;
		//ao.sig.edge = INT_EDGE;		
		ao.id = 4;
		ao.channel = 3;
		ao.data = pat.data4;
		ao.data_size = pat.DATA4_SIZE;
		if((rev=icpdasio1.setAnalogOutPatAdd(fd,ao))!=0) System.out.println("AnalogOutAdd Error Code:"+ rev);
		//ao.sig.is = INT;
		//ao.sig.edge = INT_EDGE;		
		ao.id = 5;
		ao.channel = 4;
		ao.data = pat.data5;
		ao.data_size = pat.DATA5_SIZE;
		if((rev=icpdasio1.setAnalogOutPatAdd(fd,ao))!=0) System.out.println("AnalogOutAdd Error Code:"+ rev);
		/***************************************
	 	* setup 8254 counter-0 for INT_CHAN_0 *
	 	*                                     *
	 	* 4MHz / 200 = 20KHz                  *
	 	***************************************/	
	 	/* counter-0, mode 3 */
	 	/* 0x00c8 == 100 */	
		rev = icpdasio1.setCounter(fd,0,0,0x36,0x00c8);
		if(rev != 0) System.out.println("Config 8254 Error Code : "+rev);
		/* config board interrupt */
		rev = icpdasio1.setPort(fd,"IXPIO_IMCR",INT);
		if(rev != 0) System.out.println("Config IMCR Error Code : "+rev);
		if((rev=icpdasio1.setAnalogOutDataStart(fd))!=0) System.out.println("AnalogOutStart Error Code:"+ rev);
		System.out.println("Analog ON Press <enter> for next, 'q'+<enter> to exit.");
		System.in.read(a);
		while(a[0]!=113)
		{
			if (sw==1) {
				sw=0;
				if((rev=icpdasio1.setAnalogOutDataStop(fd))!=0) System.out.println("AnalogOutStop Error Code:"+ rev);
				System.out.println("Analog OFF Press <enter> for next, 'q'+<enter> to exit.");
			}
			else {
				sw=1;	
				if((rev=icpdasio1.setAnalogOutDataStart(fd))!=0) System.out.println("AnalogOutStart Error Code:"+ rev);
				System.out.println("Analog ON Press <enter> for next, 'q'+<enter> to exit.");
			}
			System.in.read(a);
		}
		if((rev=icpdasio1.setAnalogOutKeepAlive(fd))!=0) System.out.println("Keep Alive Error Code:"+ rev);
		icpdasio1.close(fd);
		System.out.println("End of program");		
	}

}
